/*
 * This file is part of the KDE project                                      *
 *
 * SPDX-FileCopyrightText: 2015 David Rosca <nowrep@gmail.com>
 *
 * SPDX-License-Identifier: LGPL-2.0-or-later
 */

#ifndef DEBUG_P_H
#define DEBUG_P_H

#include <QLoggingCategory>

Q_DECLARE_LOGGING_CATEGORY(BLUEDAEMON)

#endif // DEBUG_P_H
