/*
 * This file is part of the KDE project
 *
 * SPDX-FileCopyrightText: 2014 David Rosca <nowrep@gmail.com>
 *
 * SPDX-License-Identifier: LGPL-2.0-or-later
 */

#include "debug_p.h"

Q_LOGGING_CATEGORY(SENDFILE, "bluedevil.sendfile")
